Class: OpenCV::CvRTParams

Inherits:
Object
  • Object
show all
Extended by:
FFI::DataConverter
Defined in:
lib/ropencv/ropencv_types.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.new(*args) ⇒ Object

Raises:

  • (ArgumentError)


43516
43517
43518
43519
43520
43521
43522
43523
# File 'lib/ropencv/ropencv_types.rb', line 43516

def self.new(*args)
    if args.first.is_a?(FFI::Pointer) || args.first.is_a?(CvRTParamsStruct)
        raise ArgumentError, "too many arguments for creating #{self.name} from Pointer" unless args.size == 1
        return super(args.first)
    end

    raise ArgumentError, "no constructor for #{self}(#{args.inspect})"
end

.nullObject

returns a null pointer to the object



43512
43513
43514
# File 'lib/ropencv/ropencv_types.rb', line 43512

def self.null
    new(CvRTParamsStruct.new)
end

Instance Method Details

#calc_var_importanceBool Also known as: get_calc_var_importance

Note:

method wrapper for bool calc_var_importance

methods



43600
43601
43602
43603
# File 'lib/ropencv/ropencv_types.rb', line 43600

def calc_var_importance()
    __validate_pointer__
    Rbind::cvrt_params_get_calc_var_importance( self)
end

#calc_var_importance=(value) ⇒ Void Also known as: set_calc_var_importance

Note:

method wrapper for bool calc_var_importance



43609
43610
43611
43612
# File 'lib/ropencv/ropencv_types.rb', line 43609

def calc_var_importance=(value)
    __validate_pointer__
    Rbind::cvrt_params_set_calc_var_importance( self, value)
end

#nactive_varsFixnum Also known as: get_nactive_vars

Note:

method wrapper for int nactive_vars



43617
43618
43619
43620
# File 'lib/ropencv/ropencv_types.rb', line 43617

def nactive_vars()
    __validate_pointer__
    Rbind::cvrt_params_get_nactive_vars( self)
end

#nactive_vars=(value) ⇒ Void Also known as: set_nactive_vars

Note:

method wrapper for int nactive_vars



43626
43627
43628
43629
# File 'lib/ropencv/ropencv_types.rb', line 43626

def nactive_vars=(value)
    __validate_pointer__
    Rbind::cvrt_params_set_nactive_vars( self, value)
end

#term_critCvTermCriteria Also known as: get_term_crit

Note:

method wrapper for CvTermCriteria term_crit



43634
43635
43636
43637
43638
43639
43640
43641
43642
# File 'lib/ropencv/ropencv_types.rb', line 43634

def term_crit()
    __validate_pointer__
    result = Rbind::cvrt_params_get_term_crit( self)
    if result.respond_to?(:__owner__?) && !result.__owner__?
    # store owner insight the pointer to not get garbage collected
        result.instance_variable_get(:@__obj_ptr__).instance_variable_set(:@__owner__,self) 
    end
    result
end

#term_crit=(value) ⇒ Void Also known as: set_term_crit

Note:

method wrapper for CvTermCriteria term_crit



43648
43649
43650
43651
# File 'lib/ropencv/ropencv_types.rb', line 43648

def term_crit=(value)
    __validate_pointer__
    Rbind::cvrt_params_set_term_crit( self, value)
end

#to_sObject

converts CvRTParams into a string by crawling through all its attributes



43589
43590
43591
# File 'lib/ropencv/ropencv_types.rb', line 43589

def to_s
    "#<CvRTParams calc_var_importance=#{self.calc_var_importance} nactive_vars=#{self.nactive_vars} term_crit=#{self.term_crit}>"
end